==> wordpress-2.8.4-he_IL.tar.gz: wordpress/wp-admin/setup-config.php <==
<?php // Modified for WPH (Translated)
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/classes.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('סליחה, אבל אני צריכה קובץ wp-config-sample.php כדי ליצור ממנו את קובץ ההגדרות. צריך להעלות את הקובץ הזה מחדש לשרת, מתוך ההתקנה של וורדפרס.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

if ( !is_writable(ABSPATH))
	wp_die("אני לא יכולה לכתוב לתיקיה של וורדפרס. צריך לשנות את ההרשאות כדי שאני אוכל לכתוב אליה, או ליצור את הקובץ wp-config.php ידנית.");

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>הקובץ '<code>wp-config.php</code>' קיים כבר. כדי להגדיר מחדש את פרטי החיבור לבסיס הנתונים, יש למחוק אותו. אפשר לנסות <a href='install.php'>להתחיל בהתקנה</a>.</p>");
// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>הקובץ '<code>wp-config.php</code>' קיים כבר בתיקיה אחת מעל התיקיה בה התקנת את וורדפרס. כדי להגדיר מחדש את פרטי החיבור לבסיס הנתונים, יש למחוק אותו. אפשר לנסות <a href='install.php'>להתחיל בהתקנה</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>וורדפרס &rsaquo; יצירת קובץ הגדרות</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />
<link rel="stylesheet" href="css/install-rtl.css" type="text/css" />
<style media="screen" type="text/css">
<!--
input {direction: ltr;}
-->
</style>
</head>
<body>
<div dir="rtl">
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>ברוכים הבאים לוורדפרס. לפני ההתקנה, אני צריכה קצת מידע על בסיס הנתונים. כדאי לברר את זה <em>לפני</em> שממשיכים.</p>
<ol>
	<li>שם בסיס הנתונים</li>
	<li>שם משתמש בבסיס הנתונים</li>
	<li>הסיסמה של אותו משתמש</li>
	<li>הכתובת (host) של בסיס הנתונים</li>
	<li>קידומת לטבלאות (בשביל להפעיל כמה התקנות של וורדפרס מבסיס נתונים אחד) </li>
</ol>
<p><strong>אם אני לא אצליח ליצור את הקובץ - אין מה לדאוג. אפשר פשוט לפתוח את הקובץ  <code>wp-config-sample.php</code> בכל עורך טקסט, למלא את הנתונים לפי ההוראות, ולשמור אותו בשם <code>wp-config.php</code>. <a href="http://docs.wph.co.il/wiki/%D7%A2%D7%A8%D7%99%D7%9B%D7%AA_%D7%A7%D7%95%D7%91%D7%A5_%D7%94%D7%94%D7%92%D7%93%D7%A8%D7%95%D7%AA">מידע נוסף על יצירת קובץ ההגדרות</a>.</strong></p>
<p>ברוב המקרים, מי שמארח את האתר שלך גם יתן לך את הפרטים האלה. אם עוד אין לך אותם - צריך לברר אותם, כאמור, לפני ההתקנה.</p>

<p class="step"><a href="setup-config.php?step=1" class="button">אפשר להתחיל!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>אלו הנתונים שאני צריכה על בסיס הנתונים שלך:</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">שם בסיס הנתונים</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>שם בסיס הנתונים של וורדפרס.</td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">שם משתמש</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>שם משתמש עם הרשאות מלאות בבסיס הנתונים הזה.</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">סיסמה</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>הסיסמה של אותו משתמש.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">כתובת (hostname)</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>הכתובת של בסיס הנתונים. ברוב מהמקרים לא צריך לשנות את זה.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">קידומת לטבלאות</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>כדי להפעיל כמה התקנות של WP מבסיס נתונים אחד, אפשר להגדיר לכל התקנה קידומת טבלאות אחרת. ברוב המקרים לא צריך לשנות את זה.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="לשמור" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen(ABSPATH . 'wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod(ABSPATH . 'wp-config.php', 0666);

	display_header();
?>
<p>זה הכל, סיימנו עם ההכנות! עכשיו אני יכולה להתחבר לבסיס הנתונים ולהתקין בו את וורדפרס.</p>
<p class="step"><a href="install.php" class="button">להתחיל בהתקנה!</a></p>
<?php
	break;
}
?>
</div><!-- /rtl -->
</body>
</html>

==> wordpress-3.2-he_IL.tar.gz: wordpress/wp-admin/setup-config.php <==
<?php // Modified for WPH (Translated)
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @internal This file must be parsable by PHP4.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**
 * We are blissfully unaware of anything.
 */
define('WP_SETUP_CONFIG', true);

/**
 * Disable error reporting
 *
 * Set this to error_reporting( E_ALL ) or error_reporting( E_ALL | E_STRICT ) for debugging
 */
error_reporting(0);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
define('WP_DEBUG', false);
/**#@-*/

require_once(ABSPATH . WPINC . '/load.php');
require_once(ABSPATH . WPINC . '/version.php');
wp_check_php_mysql_versions();

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/class-wp-error.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('סליחה, אבל אני צריכה קובץ wp-config-sample.php כדי ליצור ממנו את קובץ ההגדרות. צריך להעלות את הקובץ הזה מחדש לשרת, מתוך ההתקנה של וורדפרס.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>הקובץ '<code>wp-config.php</code>' קיים כבר. כדי להגדיר מחדש את פרטי החיבור לבסיס הנתונים, יש למחוק אותו. אפשר לנסות <a href='install.php'>להתחיל בהתקנה</a>.</p>");
// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>הקובץ '<code>wp-config.php</code>' קיים כבר בתיקיה אחת מעל התיקיה בה התקנת את וורדפרס. כדי להגדיר מחדש את פרטי החיבור לבסיס הנתונים, יש למחוק אותו. אפשר לנסות <a href='install.php'>להתחיל בהתקנה</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>וורדפרס &rsaquo; יצירת קובץ הגדרות</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />
<link rel="stylesheet" href="css/install-rtl.css" type="text/css" />
<link rel="stylesheet" href="../wp-content/languages/he_IL.css" type="text/css" />
<style media="screen" type="text/css">
<!--
input {direction: ltr;}
-->
</style>
</head>
<body>
<div dir="rtl">
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>ברוכים הבאים לוורדפרס. לפני ההתקנה, אני צריכה קצת מידע על בסיס הנתונים. כדאי לברר את זה <em>לפני</em> שממשיכים.</p>
<ol>
	<li>שם בסיס הנתונים</li>
	<li>שם משתמש בבסיס הנתונים</li>
	<li>הסיסמה של אותו משתמש</li>
	<li>הכתובת (host) של בסיס הנתונים</li>
	<li>קידומת לטבלאות (בשביל להפעיל כמה התקנות של וורדפרס מבסיס נתונים אחד) </li>
</ol>
<p><strong>אם אני לא אצליח ליצור את הקובץ - אין מה לדאוג. אפשר פשוט לפתוח את הקובץ  <code>wp-config-sample.php</code> בכל עורך טקסט, למלא את הנתונים לפי ההוראות, ולשמור אותו בשם <code>wp-config.php</code>. <a href="http://docs.wph.co.il/wiki/%D7%A2%D7%A8%D7%99%D7%9B%D7%AA_%D7%A7%D7%95%D7%91%D7%A5_%D7%94%D7%94%D7%92%D7%93%D7%A8%D7%95%D7%AA">מידע נוסף על יצירת קובץ ההגדרות</a>.</strong></p>
<p>ברוב המקרים, מי שמארח את האתר שלך גם יתן לך את הפרטים האלה. אם עוד אין לך אותם - צריך לברר אותם, כאמור, לפני ההתקנה.</p>

<p class="step"><a href="setup-config.php?step=1<?php if ( isset( $_GET['noapi'] ) ) echo '&amp;noapi'; ?>" class="button">אפשר להתחיל!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>אלו הנתונים שאני צריכה על בסיס הנתונים שלך:</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">שם בסיס הנתונים</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>שם בסיס הנתונים של וורדפרס.</td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">שם משתמש</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>שם משתמש עם הרשאות מלאות בבסיס הנתונים הזה.</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">סיסמה</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>הסיסמה של אותו משתמש.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">כתובת (hostname)</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>הכתובת של בסיס הנתונים. ברוב מהמקרים לא צריך לשנות את זה.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">קידומת לטבלאות</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>כדי להפעיל כמה התקנות של WP מבסיס נתונים אחד, אפשר להגדיר לכל התקנה קידומת טבלאות אחרת. ברוב המקרים לא צריך לשנות את זה.</td>
		</tr>
	</table>
	<?php if ( isset( $_GET['noapi'] ) ) { ?><input name="noapi" type="hidden" value="true" /><?php } ?>
	<p class="step"><input name="submit" type="submit" value="לשמור" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if ( empty($prefix) )
		$prefix = 'wp_';

	// Validate $prefix: it can only contain letters, numbers and underscores
	if ( preg_match( '|[^a-z0-9_]|i', $prefix ) )
		wp_die( /*WP_I18N_BAD_PREFIX*/'<strong>בעיה</strong>: אפשר להשתמש רק באותיות, מספרים וקווים תחתונים עבור "Table Prefix".'/*/WP_I18N_BAD_PREFIX*/ );

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( ! empty( $wpdb->error ) ) {
		$back = '<p class="step"><a href="setup-config.php?step=1" onclick="javascript:history.go(-1);return false;" class="button">Try Again</a></p>';
		wp_die( $wpdb->error->get_error_message() . $back );
	}

	// Fetch or generate keys and salts.
	$no_api = isset( $_POST['noapi'] );
	require_once( ABSPATH . WPINC . '/plugin.php' );
	require_once( ABSPATH . WPINC . '/l10n.php' );
	require_once( ABSPATH . WPINC . '/pomo/translations.php' );
	if ( ! $no_api ) {
		require_once( ABSPATH . WPINC . '/class-http.php' );
		require_once( ABSPATH . WPINC . '/http.php' );
		wp_fix_server_vars();
		/**#@+
		 * @ignore
		 */
		function get_bloginfo() {
			return ( ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . str_replace( $_SERVER['PHP_SELF'], '/wp-admin/setup-config.php', '' ) );
		}
		/**#@-*/
		$secret_keys = wp_remote_get( 'https://api.wordpress.org/secret-key/1.1/salt/' );
	}

	if ( $no_api || is_wp_error( $secret_keys ) ) {
		$secret_keys = array();
		require_once( ABSPATH . WPINC . '/pluggable.php' );
		for ( $i = 0; $i < 8; $i++ ) {
			$secret_keys[] = wp_generate_password( 64, true, true );
		}
	} else {
		$secret_keys = explode( "\n", wp_remote_retrieve_body( $secret_keys ) );
		foreach ( $secret_keys as $k => $v ) {
			$secret_keys[$k] = substr( $v, 28, 64 );
		}
	}
	$key = 0;

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				$configFile[$line_num] = str_replace("database_name_here", $dbname, $line);
				break;
			case "define('DB_USER'":
				$configFile[$line_num] = str_replace("'username_here'", "'$uname'", $line);
				break;
			case "define('DB_PASSW":
				$configFile[$line_num] = str_replace("'password_here'", "'$passwrd'", $line);
				break;
			case "define('DB_HOST'":
				$configFile[$line_num] = str_replace("localhost", $dbhost, $line);
				break;
			case '$table_prefix  =':
				$configFile[$line_num] = str_replace('wp_', $prefix, $line);
				break;
			case "define('AUTH_KEY":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_KE":
			case "define('AUTH_SAL":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_SA":
				$configFile[$line_num] = str_replace('put your unique phrase here', $secret_keys[$key++], $line );
				break;
		}
	}
	if ( ! is_writable(ABSPATH) ) :
		display_header();
?>
<p>בעיה - אי אפשר לכתוב לקובץ <code>wp-config.php</code>.</p>
<p>אפשר ליצור את הקובץ <code>wp-config.php</code> ידנית ולהדביק את הטקסט לתוכו.</p>
<textarea cols="98" rows="15" class="code"><?php
		foreach( $configFile as $line ) {
			echo htmlentities($line, ENT_COMPAT, 'UTF-8');
		}
?></textarea>
<p>כשהקובץ יהיה מוכן, אפשר ללחוץ על "להתחיל בהתקנה".</p>
<p class="step"><a href="install.php" class="button">להתחיל בהתקנה</a></p>
<?php
	else :
		$handle = fopen(ABSPATH . 'wp-config.php', 'w');
		foreach( $configFile as $line ) {
			fwrite($handle, $line);
		}
		fclose($handle);
		chmod(ABSPATH . 'wp-config.php', 0666);
		display_header();
?>
<p>זה הכל, סיימנו עם ההכנות! עכשיו אני יכולה להתחבר לבסיס הנתונים ולהתקין בו את וורדפרס.</p>

<p class="step"><a href="install.php" class="button">להתחיל בהתקנה!</a></p>
<?php
	endif;
	break;
}
?>
</div><!-- /rtl -->
</body>
</html>
